Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
Limit int
Target int
Workers int
DryRun bool
IDs []string
Period time.Duration
Database string
Session db.Session
}
func (Options) Application ¶
func (opts Options) Application(env anser.Environment, evgEnv evergreen.Environment) (*anser.Application, error)
Application is where the migrations are registered and defined, before being handed off to another calling environment for execution. See the anser documentation and the anser/example_test.go for an example.
Click to show internal directories.
Click to hide internal directories.