Documentation
¶
Index ¶
Constants ¶
const Collection = "distro"
Variables ¶
var ( // bson fields for the Distro struct IdKey = bsonutil.MustHaveTag(Distro{}, "Id") ArchKey = bsonutil.MustHaveTag(Distro{}, "Arch") PoolSizeKey = bsonutil.MustHaveTag(Distro{}, "PoolSize") ProviderKey = bsonutil.MustHaveTag(Distro{}, "Provider") ProviderSettingsKey = bsonutil.MustHaveTag(Distro{}, "ProviderSettings") SetupAsSudoKey = bsonutil.MustHaveTag(Distro{}, "SetupAsSudo") SetupKey = bsonutil.MustHaveTag(Distro{}, "Setup") UserKey = bsonutil.MustHaveTag(Distro{}, "User") SSHKeyKey = bsonutil.MustHaveTag(Distro{}, "SSHKey") SSHOptionsKey = bsonutil.MustHaveTag(Distro{}, "SSHOptions") WorkDirKey = bsonutil.MustHaveTag(Distro{}, "WorkDir") UserDataKey = bsonutil.MustHaveTag(Distro{}, "UserData") SpawnAllowedKey = bsonutil.MustHaveTag(Distro{}, "SpawnAllowed") ExpansionsKey = bsonutil.MustHaveTag(Distro{}, "Expansions") )
All is a query that returns all distros.
Functions ¶
func ByProvider ¶
ByProvider returns a query that contains a Provider selector on the string, p.
func BySpawnAllowed ¶
BySpawnAllowed returns a query that contains the SpawnAllowed selector.
func FindAllNames ¶
Types ¶
type Distro ¶
type Distro struct {
Id string `bson:"_id" json:"_id,omitempty" mapstructure:"_id,omitempty"`
Arch string `bson:"arch" json:"arch,omitempty" mapstructure:"arch,omitempty"`
WorkDir string `bson:"work_dir" json:"work_dir,omitempty" mapstructure:"work_dir,omitempty"`
PoolSize int `bson:"pool_size,omitempty" json:"pool_size,omitempty" mapstructure:"pool_size,omitempty" yaml:"poolsize"`
Provider string `bson:"provider" json:"provider,omitempty" mapstructure:"provider,omitempty"`
ProviderSettings *map[string]interface{} `bson:"settings" json:"settings,omitempty" mapstructure:"settings,omitempty"`
SetupAsSudo bool `bson:"setup_as_sudo,omitempty" json:"setup_as_sudo,omitempty" mapstructure:"setup_as_sudo,omitempty"`
Setup string `bson:"setup,omitempty" json:"setup,omitempty" mapstructure:"setup,omitempty"`
Teardown string `bson:"teardown,omitempty" json:"teardown,omitempty" mapstructure:"teardown,omitempty"`
User string `bson:"user,omitempty" json:"user,omitempty" mapstructure:"user,omitempty"`
SSHKey string `bson:"ssh_key,omitempty" json:"ssh_key,omitempty" mapstructure:"ssh_key,omitempty"`
SSHOptions []string `bson:"ssh_options,omitempty" json:"ssh_options,omitempty" mapstructure:"ssh_options,omitempty"`
UserData string `bson:"user_data,omitempty" json:"user_data,omitempty" mapstructure:"user_data,omitempty"`
SpawnAllowed bool `bson:"spawn_allowed" json:"spawn_allowed,omitempty" mapstructure:"spawn_allowed,omitempty"`
Expansions []Expansion `bson:"expansions,omitempty" json:"expansions,omitempty" mapstructure:"expansions,omitempty"`
}
func (*Distro) BinaryName ¶
func (*Distro) ExecutableSubPath ¶
ExecutableSubPath returns the directory containing the compiled agents.
func (*Distro) GenerateName ¶
GenerateName generates a unique instance name for a distro.
func (*Distro) IsEphemeral ¶
type ValidateFormat ¶
type ValidateFormat string
Click to show internal directories.
Click to hide internal directories.