Documentation
¶
Index ¶
Constants ¶
const ( TaskJSONPluginName = "json" TaskJSONSend = "send" TaskJSONGet = "get" TaskJSONGetHistory = "get_history" TaskJSONHistory = "history" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CommitInfo ¶
type CommitInfo struct {
Author string `json:"author"`
Message string `json:"message"`
CreateTime time.Time `json:"create_time"`
Revision string `json:"revision"`
VersionId string `json:"version_id"`
}
CommitInfo represents the information about the commit associated with the version of a given project. This is displayed at the top of each header for each project.
type TaskForVersionId ¶
TaskForVersionId contains the id information about the group of tasks including the version id and the revision order number.
type TaskInfo ¶
type TaskInfo struct {
TaskId string `bson:"t_id" json:"task_id"`
TaskName string `bson:"tn" json:"task_name"`
Variant string `bson:"var" json:"variant"`
Data interface{} `bson:"d" json:"data"`
}
TaskInfo contains the relevant TaskJSON information the tasks associated with a version.
type TaskJSONPlugin ¶
type TaskJSONPlugin struct{}
TaskJSONPlugin handles thet
func (*TaskJSONPlugin) Configure ¶
func (jsp *TaskJSONPlugin) Configure(map[string]interface{}) error
func (*TaskJSONPlugin) GetPanelConfig ¶
func (jsp *TaskJSONPlugin) GetPanelConfig() (*plugin.PanelConfig, error)
GetPanelConfig is required to fulfill the Plugin interface. This plugin does not have any UI hooks.
func (*TaskJSONPlugin) GetUIHandler ¶
func (hwp *TaskJSONPlugin) GetUIHandler() http.Handler
func (*TaskJSONPlugin) Name ¶
func (jsp *TaskJSONPlugin) Name() string
Name implements Plugin Interface.
type TasksForVersion ¶
type TasksForVersion struct {
Id TaskForVersionId `bson:"_id" json:"id"`
Tasks []TaskInfo `bson:"t" json:"tasks"`
}
TasksForVersion is a list of tasks that are associated with a given version id.
type VersionData ¶
type VersionData struct {
JSONTasks []TaskInfo `json:"json_tasks"`
Commit CommitInfo `json:"commit_info"`
LastRevision bool `json:"last_revision"`
}
VersionData includes the TaskInfo, and Commit information for a given version.